@@ -20,15 +20,16 @@ ch = logging.StreamHandler()
 ch.setFormatter(formatter)
 logger.addHandler(ch)
 
-if sys.platform == 'darwin':
-    address = '/var/run/syslog'
-elif os.path.exists('/dev/log'):
-    address = '/dev/log'
-else:
-    address = ('localhost', 514)
+# TODO(dustin): This all does not work for a Linux system. Just omit the "address" parameter completely.
+#if sys.platform == 'darwin':
+#    address = '/var/run/syslog'
+#elif os.path.exists('/dev/log'):
+#    address = '/dev/log'
+#else:
+#    address = ('localhost', 514)
 
 ch = logging.handlers.SysLogHandler(
-        address, 
+#        address, 
         facility=logging.handlers.SysLogHandler.LOG_LOCAL0)
 
 ch.setFormatter(formatter)
